==> v0.13.11.tar.gz: git-next/crates/cli/src/server/actor/messages.rs <==
//
use actix::{Message, Recipient};
use derive_more::Constructor;

use git_next_core::{
    git::{self, forge::commit::Status, graph::Log, Commit},
    message,
    server::{AppConfig, Storage},
    webhook::{push::Branch, Push},
    ForgeAlias, RepoAlias, RepoBranches, RepoConfig,
};

use std::net::SocketAddr;

// receive server config
message!(
    ReceiveAppConfig,
    AppConfig,
    "Notification of newly loaded server configuration.

This message will prompt the `git-next` server to stop and restart all repo-actors.

Contains the new server configuration."
);

// receive valid server config
#[derive(Clone, Debug, PartialEq, Eq, Constructor)]
pub struct ValidAppConfig {
    pub app_config: AppConfig,
    pub socket_address: SocketAddr,
    pub storage: Storage,
}
message!(
    ReceiveValidAppConfig,
    ValidAppConfig,
    "Notification of validated server configuration."
);

message!(Shutdown, "Notification to shutdown the server actor");

#[derive(Clone, Debug, PartialEq, Eq, Message)]
#[rtype(result = "()")]
pub enum ServerUpdate {
    /// List of all configured forges and aliases
    AppConfigLoaded { app_config: ValidAppConfig },

    RepoUpdate {
        forge_alias: ForgeAlias,
        repo_alias: RepoAlias,
        repo_update: RepoUpdate,
    },
}

#[derive(Clone, Debug, PartialEq, Eq)]
pub enum RepoUpdate {
    Branches {
        branches: RepoBranches,
    },
    Log {
        log: Log,
    },
    ValidateRepo,
    Okay {
        main: Commit,
        next: Commit,
        dev: Commit,
    },
    Alert {
        alert: String,
    },
    CheckingCI,
    AdvancingNext {
        commit: git::Commit,
        force: git::push::Force,
    },
    AdvancingMain {
        commit: git::Commit,
    },
    Opening,
    LoadingConfigFromRepo,
    ReceiveCIStatus {
        status: Status,
    },
    ReceiveRepoConfig {
        repo_config: RepoConfig,
    },
    RegisteringWebhook,
    UnregisteringWebhook,
    WebhookReceived {
        branch: Branch,
        push: Push,
    },
    RegisteredWebhook,
    Opened,
    NextUpdated,
    MainUpdated,
}

message!(
    SubscribeToUpdates,
    Recipient<ServerUpdate>,
    "Subscribe to receive updates from the server"
);

/// Sends a channel to be used to shutdown the server
#[derive(Message, Constructor)]
#[rtype(result = "()")]
pub struct ShutdownTrigger(std::sync::mpsc::Sender<String>);
impl ShutdownTrigger {
    pub fn peel(self) -> std::sync::mpsc::Sender<String> {
        self.0
    }
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/server/actor/messages.rs <==
//
use std::net::SocketAddr;

use derive_more::Constructor;
use tokio::sync::mpsc::Sender;

use git_next_core::{
    git::{self, forge::commit::Status, graph::Log, Commit},
    message,
    server::{AppConfig, Storage},
    webhook::{push::Branch, Push},
    ForgeAlias, RepoAlias, RepoBranches, RepoConfig,
};

// receive server config
message!(
    ReceiveAppConfig,
    AppConfig,
    "Notification of newly loaded server configuration.

This message will prompt the `git-next` server to stop and restart all repo-actors.

Contains the new server configuration."
);

// receive valid server config
#[derive(Clone, Debug, PartialEq, Eq, Constructor)]
pub struct ValidAppConfig {
    pub app_config: AppConfig,
    pub socket_address: SocketAddr,
    pub storage: Storage,
}
message!(
    ReceiveValidAppConfig,
    ValidAppConfig,
    "Notification of validated server configuration."
);

message!(Shutdown, "Notification to shutdown the server actor");

#[derive(Clone, Debug, PartialEq, Eq)]
pub enum ServerUpdate {
    /// List of all configured forges and aliases
    AppConfigLoaded { app_config: ValidAppConfig },

    RepoUpdate {
        forge_alias: ForgeAlias,
        repo_alias: RepoAlias,
        repo_update: RepoUpdate,
    },
}

#[derive(Clone, Debug, PartialEq, Eq)]
pub enum RepoUpdate {
    Branches {
        branches: RepoBranches,
    },
    Log {
        log: Log,
    },
    ValidateRepo,
    Okay {
        main: Commit,
        next: Commit,
        dev: Commit,
    },
    Alert {
        alert: String,
    },
    CheckingCI,
    AdvancingNext {
        commit: git::Commit,
        force: git::push::Force,
    },
    AdvancingMain {
        commit: git::Commit,
    },
    Opening,
    LoadingConfigFromRepo,
    ReceiveCIStatus {
        status: Status,
    },
    ReceiveRepoConfig {
        repo_config: RepoConfig,
    },
    RegisteringWebhook,
    UnregisteringWebhook,
    WebhookReceived {
        branch: Branch,
        push: Push,
    },
    RegisteredWebhook,
    Opened,
    NextUpdated,
    MainUpdated,
}

/// Sends a channel to be used to shutdown the server
#[derive(Constructor)]
pub struct ShutdownTrigger(Sender<String>);
impl ShutdownTrigger {
    pub fn peel(self) -> Sender<String> {
        self.0
    }
}
